import { __decorate, __metadata } from 'tslib';
import { isDevMode, TemplateRef, ViewContainerRef, Input, Directive, Component, NgModule, ɵɵdefineInjectable, Injectable } from '@angular/core';
import { isOn, set } from 'feature-toggle-service';
import { CommonModule } from '@angular/common';

let FeatureToggleDirective = class FeatureToggleDirective {
    constructor(templateRef, viewContainer) {
        this.templateRef = templateRef;
        this.viewContainer = viewContainer;
        this.isOn = false;
    }
    ngOnInit() {
        if (!this.featureToggle) {
            throw new Error('Attribute `featureToggle` should not be null or empty');
        }
        this.shouldRender();
    }
    ngDoCheck() {
        if (this.isOn !== this.isOnCheck(this.featureToggle)) {
            this.shouldRender();
        }
    }
    shouldRender() {
        this.isOn = this.isOnCheck(this.featureToggle);
        if (this.isOn) {
            this.viewContainer.createEmbeddedView(this.templateRef);
        }
        else {
            this.viewContainer.clear();
        }
    }
    isOnCheck(featureToggle) {
        const DEV_MODE = isDevMode();
        const isFeatureToggleOn = (toggle) => toggle[0] === '!' ? !isOn(toggle.replace('!', '')) : isOn(toggle);
        if (typeof featureToggle === 'string') {
            return isFeatureToggleOn(featureToggle);
        }
        else if (Array.isArray(featureToggle)) {
            return featureToggle.every(isFeatureToggleOn);
        }
        else if (DEV_MODE) {
            console.error('`NgxFeatureToggle`: `featureToggle` should receive an array or an string as a value.');
        }
    }
};
FeatureToggleDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], FeatureToggleDirective.prototype, "featureToggle", void 0);
FeatureToggleDirective = __decorate([
    Directive({
        // tslint:disable-next-line: directive-selector
        selector: '[featureToggle]',
    }),
    __metadata("design:paramtypes", [TemplateRef,
        ViewContainerRef])
], FeatureToggleDirective);

let FeatureToggleProviderComponent = class FeatureToggleProviderComponent {
    constructor() {
        this.features = {};
        this.currentConfig = {};
    }
    ngOnInit() {
        if (typeof this.features !== 'object') {
            throw new Error('Attribute `features` should not be null or empty');
        }
        this.setFeatureToggles();
    }
    ngDoCheck() {
        this.setFeatureToggles();
    }
    setFeatureToggles() {
        if (this.currentConfig !== this.features) {
            this.currentConfig = this.features;
            set(this.features);
        }
    }
};
__decorate([
    Input(),
    __metadata("design:type", Object)
], FeatureToggleProviderComponent.prototype, "features", void 0);
FeatureToggleProviderComponent = __decorate([
    Component({
        selector: 'feature-toggle-provider',
        template: `
    <ng-content></ng-content>
  `
    })
], FeatureToggleProviderComponent);

let FeatureToggleModule = class FeatureToggleModule {
};
FeatureToggleModule = __decorate([
    NgModule({
        declarations: [FeatureToggleProviderComponent, FeatureToggleDirective],
        exports: [FeatureToggleProviderComponent, FeatureToggleDirective],
        imports: [CommonModule],
    })
], FeatureToggleModule);

let NgxFeatureToggleCanActivateGuard = class NgxFeatureToggleCanActivateGuard {
    isDevMode() {
        return isDevMode();
    }
    canActivate(route) {
        const DEV_MODE = this.isDevMode();
        if (!route || !route.data || !route.data.featureToggle) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanActivateGuard` need to receive `featureToggle` as data in your route configuration.');
            }
            return false;
        }
        const isFeatureToggleOn = (toggle) => toggle[0] === '!' ? !isOn(toggle.replace('!', '')) : isOn(toggle);
        if (typeof route.data.featureToggle === 'string') {
            return isFeatureToggleOn(route.data.featureToggle);
        }
        else if (Array.isArray(route.data.featureToggle)) {
            return route.data.featureToggle.every(isFeatureToggleOn);
        }
        if (DEV_MODE) {
            console.error('`NgxFeatureToggleCanActivateGuard` need to receive `featureToggle` as data as an array or string in your route configuration.');
        }
        return false;
    }
};
NgxFeatureToggleCanActivateGuard.ɵprov = ɵɵdefineInjectable({ factory: function NgxFeatureToggleCanActivateGuard_Factory() { return new NgxFeatureToggleCanActivateGuard(); }, token: NgxFeatureToggleCanActivateGuard, providedIn: "root" });
NgxFeatureToggleCanActivateGuard = __decorate([
    Injectable({ providedIn: 'root' })
], NgxFeatureToggleCanActivateGuard);

let NgxFeatureToggleCanActivateChildGuard = class NgxFeatureToggleCanActivateChildGuard {
    isDevMode() {
        return isDevMode();
    }
    canActivateChild(route) {
        const DEV_MODE = this.isDevMode();
        if (!route || !route.data || !route.data.featureToggle) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanActivateChildGuard` need to receive `featureToggle` as data in your route configuration.');
            }
            return false;
        }
        const isFeatureToggleOn = (toggle) => toggle[0] === '!' ? !isOn(toggle.replace('!', '')) : isOn(toggle);
        if (typeof route.data.featureToggle === 'string') {
            return isFeatureToggleOn(route.data.featureToggle);
        }
        else if (Array.isArray(route.data.featureToggle)) {
            return route.data.featureToggle.every(isFeatureToggleOn);
        }
        if (DEV_MODE) {
            console.error('`NgxFeatureToggleCanActivateChildGuard` need to receive `featureToggle` as data as an array or string in your route configuration.');
        }
        return false;
    }
};
NgxFeatureToggleCanActivateChildGuard.ɵprov = ɵɵdefineInjectable({ factory: function NgxFeatureToggleCanActivateChildGuard_Factory() { return new NgxFeatureToggleCanActivateChildGuard(); }, token: NgxFeatureToggleCanActivateChildGuard, providedIn: "root" });
NgxFeatureToggleCanActivateChildGuard = __decorate([
    Injectable({ providedIn: 'root' })
], NgxFeatureToggleCanActivateChildGuard);

let NgxFeatureToggleCanLoadGuard = class NgxFeatureToggleCanLoadGuard {
    isDevMode() {
        return isDevMode();
    }
    canLoad(route) {
        const DEV_MODE = this.isDevMode();
        if (!route || !route.data || !route.data.featureToggle) {
            if (DEV_MODE) {
                console.error('`NgxFeatureToggleCanLoadGuard` need to receive `featureToggle` as data in your route configuration.');
            }
            return false;
        }
        const isFeatureToggleOn = (toggle) => toggle[0] === '!' ? !isOn(toggle.replace('!', '')) : isOn(toggle);
        if (typeof route.data.featureToggle === 'string') {
            return isFeatureToggleOn(route.data.featureToggle);
        }
        else if (Array.isArray(route.data.featureToggle)) {
            return route.data.featureToggle.every(isFeatureToggleOn);
        }
        if (DEV_MODE) {
            console.error('`NgxFeatureToggleCanLoadGuard` need to receive `featureToggle` as data as an array or string in your route configuration.');
        }
        return false;
    }
};
NgxFeatureToggleCanLoadGuard.ɵprov = ɵɵdefineInjectable({ factory: function NgxFeatureToggleCanLoadGuard_Factory() { return new NgxFeatureToggleCanLoadGuard(); }, token: NgxFeatureToggleCanLoadGuard, providedIn: "root" });
NgxFeatureToggleCanLoadGuard = __decorate([
    Injectable({ providedIn: 'root' })
], NgxFeatureToggleCanLoadGuard);

/*
 * Public API Surface of ngx-feature-toggle
 */

/**
 * Generated bundle index. Do not edit.
 */

export { FeatureToggleDirective, FeatureToggleModule, FeatureToggleProviderComponent, NgxFeatureToggleCanActivateChildGuard, NgxFeatureToggleCanActivateGuard, NgxFeatureToggleCanLoadGuard };
//# sourceMappingURL=ngx-feature-toggle.js.map
